# pywdpa 0.1.1

* Dependence to `python-dotenv` has been removed.
* The `.env` and `settings.py` files have to be created in the user
  current working directory.
* See <https://pypi.org/project/python-dotenv/>.
* Tests have been added for functions.

# pywdpa 0.1

* First release of the package.
* Two functions `get_token()` and `get_wdpa()`.
* Dependence to `python-dotenv` to manage WDPA API token.
